==> cryptoapis-1.4.0.tar: src/cryptoapis_get_wallet_transaction_details_by_transaction_idribs.erl <==
-module(cryptoapis_get_wallet_transaction_details_by_transaction_idribs).

-export([encode/1]).

-export_type([cryptoapis_get_wallet_transaction_details_by_transaction_idribs/0]).

-type cryptoapis_get_wallet_transaction_details_by_transaction_idribs() ::
    #{ 'locktime' := integer(),
       'size' := integer(),
       'vSize' := integer(),
       'version' := integer(),
       'vin' := list(),
       'vout' := list(),
       'contract' := binary(),
       'gasLimit' := binary(),
       'gasPrice' := cryptoapis_get_transaction_details_by_transaction_idribsbsc_gas_price:cryptoapis_get_transaction_details_by_transaction_idribsbsc_gas_price(),
       'gasUsed' := binary(),
       'inputData' := binary(),
       'nonce' := integer(),
       'transactionStatus' := binary(),
       'bindingSig' := binary(),
       'expiryHeight' := integer(),
       'joinSplitPubKey' := binary(),
       'joinSplitSig' := binary(),
       'overwintered' := boolean(),
       'vJoinSplit' => list(),
       'vShieldedOutput' => list(),
       'vShieldedSpend' => list(),
       'valueBalance' := binary(),
       'versionGroupId' := binary()
     }.

encode(#{ 'locktime' := Locktime,
          'size' := Size,
          'vSize' := VSize,
          'version' := Version,
          'vin' := Vin,
          'vout' := Vout,
          'contract' := Contract,
          'gasLimit' := GasLimit,
          'gasPrice' := GasPrice,
          'gasUsed' := GasUsed,
          'inputData' := InputData,
          'nonce' := Nonce,
          'transactionStatus' := TransactionStatus,
          'bindingSig' := BindingSig,
          'expiryHeight' := ExpiryHeight,
          'joinSplitPubKey' := JoinSplitPubKey,
          'joinSplitSig' := JoinSplitSig,
          'overwintered' := Overwintered,
          'vJoinSplit' := VJoinSplit,
          'vShieldedOutput' := VShieldedOutput,
          'vShieldedSpend' := VShieldedSpend,
          'valueBalance' := ValueBalance,
          'versionGroupId' := VersionGroupId
        }) ->
    #{ 'locktime' => Locktime,
       'size' => Size,
       'vSize' => VSize,
       'version' => Version,
       'vin' => Vin,
       'vout' => Vout,
       'contract' => Contract,
       'gasLimit' => GasLimit,
       'gasPrice' => GasPrice,
       'gasUsed' => GasUsed,
       'inputData' => InputData,
       'nonce' => Nonce,
       'transactionStatus' => TransactionStatus,
       'bindingSig' => BindingSig,
       'expiryHeight' => ExpiryHeight,
       'joinSplitPubKey' => JoinSplitPubKey,
       'joinSplitSig' => JoinSplitSig,
       'overwintered' => Overwintered,
       'vJoinSplit' => VJoinSplit,
       'vShieldedOutput' => VShieldedOutput,
       'vShieldedSpend' => VShieldedSpend,
       'valueBalance' => ValueBalance,
       'versionGroupId' => VersionGroupId
     }.

==> cryptoapis-1.7.0.tar: src/cryptoapis_get_wallet_transaction_details_by_transaction_idribs.erl <==
-module(cryptoapis_get_wallet_transaction_details_by_transaction_idribs).

-export([encode/1]).

-export_type([cryptoapis_get_wallet_transaction_details_by_transaction_idribs/0]).

-type cryptoapis_get_wallet_transaction_details_by_transaction_idribs() ::
    #{ 'locktime' := integer(),
       'size' := integer(),
       'vSize' := integer(),
       'version' := integer(),
       'vin' := list(),
       'vout' := list(),
       'contract' := binary(),
       'gasLimit' := binary(),
       'gasPrice' := cryptoapis_get_wallet_transaction_details_by_transaction_idribsp_gas_price:cryptoapis_get_wallet_transaction_details_by_transaction_idribsp_gas_price(),
       'gasUsed' := binary(),
       'inputData' := binary(),
       'nonce' := integer(),
       'transactionStatus' := binary(),
       'bindingSig' := binary(),
       'expiryHeight' := integer(),
       'joinSplitPubKey' := binary(),
       'joinSplitSig' := binary(),
       'overwintered' := boolean(),
       'vJoinSplit' => list(),
       'vShieldedOutput' => list(),
       'vShieldedSpend' => list(),
       'valueBalance' := binary(),
       'versionGroupId' := binary(),
       'amount' := binary(),
       'bandwidthUsed' := binary(),
       'energyUsed' := binary(),
       'hasInternalTransactions' := boolean(),
       'hasTokenTransfers' := boolean(),
       'input' := binary(),
       'status' := binary()
     }.

encode(#{ 'locktime' := Locktime,
          'size' := Size,
          'vSize' := VSize,
          'version' := Version,
          'vin' := Vin,
          'vout' := Vout,
          'contract' := Contract,
          'gasLimit' := GasLimit,
          'gasPrice' := GasPrice,
          'gasUsed' := GasUsed,
          'inputData' := InputData,
          'nonce' := Nonce,
          'transactionStatus' := TransactionStatus,
          'bindingSig' := BindingSig,
          'expiryHeight' := ExpiryHeight,
          'joinSplitPubKey' := JoinSplitPubKey,
          'joinSplitSig' := JoinSplitSig,
          'overwintered' := Overwintered,
          'vJoinSplit' := VJoinSplit,
          'vShieldedOutput' := VShieldedOutput,
          'vShieldedSpend' := VShieldedSpend,
          'valueBalance' := ValueBalance,
          'versionGroupId' := VersionGroupId,
          'amount' := Amount,
          'bandwidthUsed' := BandwidthUsed,
          'energyUsed' := EnergyUsed,
          'hasInternalTransactions' := HasInternalTransactions,
          'hasTokenTransfers' := HasTokenTransfers,
          'input' := Input,
          'status' := Status
        }) ->
    #{ 'locktime' => Locktime,
       'size' => Size,
       'vSize' => VSize,
       'version' => Version,
       'vin' => Vin,
       'vout' => Vout,
       'contract' => Contract,
       'gasLimit' => GasLimit,
       'gasPrice' => GasPrice,
       'gasUsed' => GasUsed,
       'inputData' => InputData,
       'nonce' => Nonce,
       'transactionStatus' => TransactionStatus,
       'bindingSig' => BindingSig,
       'expiryHeight' => ExpiryHeight,
       'joinSplitPubKey' => JoinSplitPubKey,
       'joinSplitSig' => JoinSplitSig,
       'overwintered' => Overwintered,
       'vJoinSplit' => VJoinSplit,
       'vShieldedOutput' => VShieldedOutput,
       'vShieldedSpend' => VShieldedSpend,
       'valueBalance' => ValueBalance,
       'versionGroupId' => VersionGroupId,
       'amount' => Amount,
       'bandwidthUsed' => BandwidthUsed,
       'energyUsed' => EnergyUsed,
       'hasInternalTransactions' => HasInternalTransactions,
       'hasTokenTransfers' => HasTokenTransfers,
       'input' => Input,
       'status' => Status
     }.
